/*===========================================================================
 * QtAdvancedDockingSystem - DockManager
 *===========================================================================*/
ads--CDockManager
{
	padding: 0px;
}


ads--CDockContainerWidget
{
	background: red;
}

ads--CDockSplitter::handle
{
	background: darkred;
}


ads--CDockSplitter::handle:horizontal
{
    image: none;
    
}

ads--CDockSplitter::handle:vertical
{
    image: none;
}


/*===========================================================================
 * QtAdvancedDockingSystem - DockArea
 *===========================================================================*/
ads--CDockAreaWidget
{
    border-top: none;
    background: red;
}


ads--CDockAreaTitleBar
{
	background: white;
	border-bottom: 1px solid green;
	min-height: 23px;
}


ads--CDockAreaTitleBar:disabled
{
	border-bottom: 1px solid blue;
}

ads--CDockAreaTitleBar > QToolButton
{
	background: white;
	padding: 1 2px;
	qproperty-iconSize: 14px;
}

ads--CDockAreaTitleBar > QToolButton:hover
{
	background: grey;
}

ads--CDockAreaTitleBar > QToolButton:pressed
{
	border: 1px solid green;
	background: darkgreen;
}


ads--CDockAreaTabBar
{

}


#tabsContainerWidget
{
	background: white;
}


/*===========================================================================
 * QtAdvancedDockingSystem - DockArea Titlebar Buttons
 *===========================================================================*/
#tabsMenuButton::menu-indicator
{
    image: none;
}

#tabsMenuButton
{
    qproperty-icon: url(icon:/normal/toolbutton_down_arrow.svg);
	qproperty-iconSize: 8px;
}

#dockAreaCloseButton
{
    qproperty-icon: url(icon:/normal/dockwidget_close_button.svg);
	qproperty-iconSize: 12px;
}

#detachGroupButton
{
    qproperty-icon: url(icon:/normal/dockwidget_float_button.svg);
    qproperty-iconSize: 11px;
}

#dockAreaAutoHideButton
{
    qproperty-icon: url(icon:/normal/dockwidget_pin_button.svg);
    qproperty-iconSize: 16px;
}


/*===========================================================================
 * QtAdvancedDockingSystem - Dock Widget Tab
 *===========================================================================*/
ads--CDockWidgetTab
{
    padding: 0 0px;
}

ads--CDockWidgetTab[activeTab="false"]
{
	background: white;
	border-right: 1px solid red;
}


ads--CDockWidgetTab[activeTab="true"]
{
	background: green;
}

ads--CDockWidgetTab > QLabel
{
   ;
}


ads--CDockWidgetTab[activeTab="true"]:disabled
{
	background: blue;
}

ads--CDockWidgetTab[activeTab="true"] #dockWidgetTabLabel
{
	color: red;
}

#tabCloseButton
{
	margin-top: 2px;
	background: none;
	border: none;
	padding: 2px 0px;
	qproperty-icon: url(icon:/normal/dockwidget_tab_close_button.svg);
	qproperty-iconSize: 11px;
	min-height: 11px;
}

#tabCloseButton:hover
{
	border: 1px solid rgba(0, 0, 0, 32);
	background: rgba(0, 0, 0, 16);
}

#tabCloseButton:pressed
{
	background: rgba(0, 0, 0, 32);
}


/*===========================================================================
 * QtAdvancedDockingSystem - Dock Widget
 *===========================================================================*/
ads--CDockWidget > QToolBar
{
    border-bottom: 1px solid palette(light);
}

ads--CDockWidget
{
	border: 1px solid white;
	border-top: none;
	background: red;
}

/**
 * The border comes from the itemview that is inside of the dock widget so we
 * we can disable the border
 */
ads--CDockWidget[ItemViewContainer="true"]
{
	border-left: none;
	border-right: none;
	border-bottom: none;
}


ads--CDockWidget[ItemViewContainer="true"] QtLabb--CHeaderWidget
{
    border-left: 1px solid white;
    border-right: 1px solid white;
}


ads--CDockWidget[ItemViewContainer="true"] QTableView
{
	gridline-color: white;
	padding-left: -1px;
	padding-right: -1px;
	background-color: darkred;
}


ads--CDockWidget[ItemViewContainer="true"]  QHeaderView::section:horizontal:first
{
     border-left: 1px solid white;
}

ads--CDockWidget[ItemViewContainer="true"]  QHeaderView::section:horizontal:last
{
     border-right: 1px solid white;
}


QWidget[dockWidgetContent="true"]
{
	border: none;
}


/*===========================================================================
 * QtAdvancedDockingSystem - Overlay
 *===========================================================================*/
ads--CDockOverlayCross
{
	qproperty-iconFrameColor: green;
	qproperty-iconBackgroundColor: palette(base);
	qproperty-iconOverlayColor: green;
	qproperty-iconArrowColor: orange;
	qproperty-iconShadowColor: rgb(0, 0, 0);
}


/*****************************************************************************
 *
 * Styling of auto hide functionality
 *
 *****************************************************************************/
 
 
/*****************************************************************************
 * CAutoHideTab
 *****************************************************************************/
ads--CAutoHideTab {
	qproperty-iconSize: 16px 16px;/* this is optional in case you would like to change icon size*/
	background: none;
	border: none;
	padding-left: 2px;
	padding-right: 0px;
	text-align: center;
	min-height: 20px;
	padding-bottom: 2px;
}


ads--CAutoHideTab:hover
{
	color: palette(highlight);
}



ads--CAutoHideTab[iconOnly="false"][sideBarLocation="0"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="2"]  {
	border-top: 5px solid rgba(255, 255, 255, 32);
	padding-top: 2px;
	padding-bottom: 4px;
}


ads--CAutoHideTab[iconOnly="false"][sideBarLocation="1"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="3"] {
	border-bottom: 5px solid rgba(255, 255, 255, 32);
	padding-bottom: 2px;
	padding-top: 4px;
}



ads--CAutoHideTab:hover[iconOnly="false"][sideBarLocation="0"],
ads--CAutoHideTab:hover[iconOnly="false"][sideBarLocation="2"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="0"][activeTab="true"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="2"][activeTab="true"]  {
	border-top: 5px solid palette(highlight);
}


ads--CAutoHideTab:hover[iconOnly="false"][sideBarLocation="1"],
ads--CAutoHideTab:hover[iconOnly="false"][sideBarLocation="3"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="1"][activeTab="true"],
ads--CAutoHideTab[iconOnly="false"][sideBarLocation="3"][activeTab="true"] {
	border-bottom: 5px solid palette(highlight);
}


/*****************************************************************************
 * CAutoHideSideBar
 *****************************************************************************/
ads--CAutoHideSideBar{
	background: palette(window);
	border: none;
	qproperty-spacing: 12;
}

#sideTabsContainerWidget {
	background: transparent;
}


/*****************************************************************************
 * CAutoHideDockContainer
 *****************************************************************************/
ads--CAutoHideDockContainer {
	background: palette(window);
}


ads--CAutoHideDockContainer ads--CDockAreaTitleBar {
	background: palette(highlight);
	padding: 0px;
	border: none;
}


/*
 * This is required because the ads--CDockAreaWidget[focused="true"] will 
 * overwrite the ads--CAutoHideDockContainer ads--CDockAreaTitleBar rule
 */
ads--CAutoHideDockContainer ads--CDockAreaWidget[focused="true"] ads--CDockAreaTitleBar {
	background: palette(highlight);
	padding: 0px;
	border: none;
}


#autoHideTitleLabel {
	padding-left: 4px;
	color: red;
}


/*****************************************************************************
 * CAutoHideDockContainer titlebar buttons
 *****************************************************************************/
ads--CAutoHideDockContainer #dockAreaAutoHideButton {
	qproperty-icon: url(icon:/normal/dockwidget_pin_button_pinned.svg);
	qproperty-iconSize: 16px;
}


ads--CAutoHideDockContainer #dockAreaCloseButton{
	qproperty-icon: url(icon:/normal/dockwidget_tab_close_button.svg);
}


ads--CAutoHideDockContainer #dockAreaMinimizeButton {
	qproperty-icon: url(icon:/normal/dockwidget_minimize_button.svg);
	qproperty-iconSize: 16px;	
}


ads--CAutoHideDockContainer ads--CTitleBarButton {
	background: palette(highlight);
}


ads--CAutoHideDockContainer ads--CTitleBarButton:hover {
	background: rgba(0, 0, 0, 32);
	border: none;
}

ads--CAutoHideDockContainer ads--CTitleBarButton:pressed {
	background: rgba(0, 0, 0, 64);
	border: none;
}


/*****************************************************************************
 * CResizeHandle
 *****************************************************************************/
ads--CResizeHandle {
	background: lightcoral;
}

ads--CResizeHandle:hover {
	background-color: darkgreen;
}
